(history)=
# History

Below, some more information on the history behind the package.

## Creation

```{margin}
<sup>1</sup>More on our GlacioHack founder at [adehecq.github.io](https://adehecq.github.io/).
```

xDEM was created during the **[GlacioHack](https://github.com/GlacioHack) hackathon**, that was initiated by
Amaury Dehecq<sup>1</sup> and took place online on November 8, 2020.

```{margin}
<sup>2</sup>Check-out [glaciology.ch](https://glaciology.ch) on our founding group of VAW glaciology!
```

The initial core development of xDEM was performed by members of the Glaciology group of the Laboratory of Hydraulics, Hydrology and
Glaciology (VAW) at ETH Zürich<sup>2</sup>, with contributions by members of the University of Oslo, the University of Washington, and University
Grenoble Alpes.

## Joining effort with **demcompare**

In 2024, xDEM and [demcompare](https://github.com/CNES/demcompare) joined efforts in the perspective of
merging the best of both packages into one, and to jointly continue the development of new features for
analyzing elevation data with a larger expertise pool.

[demcompare](https://github.com/CNES/demcompare) is a tool developed by the CNES (French Space Agency) to
support its 3D satellite missions in analyzing elevation data, for instance from stereophotogrammetric DEMs
that can be generated with [CARS](https://github.com/CNES/cars).

## Current team

```{margin}
<sup>3</sup>More on CNES's 3D missions on the [CO3D constellation page](https://cnes.fr/en/projects/co3d).
```

The current lead development team includes **researchers in Earth observation and engineers from
[CNES](https://cnes.fr/en)** (French Space Agency). We specialize in elevation data analysis, for application in Earth
science or for operational use for 3D satellite missions<sup>3</sup>.

Other volunteer contributors span diverse scientific backgrounds in industry or research. We welcome
any new contributors! See how to contribute on [the dedicated page of our repository](https://github.com/GlacioHack/xdem/blob/main/CONTRIBUTING.md).
